/**
 * 课程任务接口
 */
export interface LessonTask {
  /** 任务ID */
  id: number;
  /** 课程名称 */
  courseName: string;
  /** 微课名称 */
  microLessonName: string;
  /** 用户ID */
  userId: number;
  /** 进度状态 */
  progressStatus: number;
  /** 脚本上传时间（时间戳） */
  scriptUploadTime?: number;
  /** 脚本确认时间（时间戳） */
  scriptConfirmTime?: number;
  /** 视频拍摄时间（时间戳） */
  videoCaptureTime?: number;
  /** 视频确认时间（时间戳） */
  videoConfirmTime?: number;
  /** 任务完成时间（时间戳） */
  finishTime?: number;
  /** 建议/反馈信息 */
  advise?: string;
  /** 创建时间（时间戳） */
  createdAt: number;
  /** 更新时间（时间戳） */
  updatedAt: number;
  /** 脚本文件路径 */
  script_file?: string;
  /** 视频拍摄文件路径 */
  capture_file?: string;
  /** 素材文件路径 */
  material_file?: string;
}

export interface LessonTaskPagination {
  content: LessonTask[];
  totalElements: number;
  totalPages: number;
  size: number;
  number: number;
  first: boolean;
  last: boolean;
  empty: boolean;
}

// 进度状态枚举
export enum ProgressStatus {
  SCRIPT_UPLOAD = 0,    // 脚本上传
  SCRIPT_CONFIRM = 1,   // 脚本确认
  VIDEO_CAPTURE = 2,    // 视频拍摄
  POST_PRODUCTION = 3,  // 后期制作
  FINISHED = 4,         // 任务完成
}

export type FileUploadDestination = "qq" | "wechat" | "platform";

/**
 * 创建课程任务请求参数接口
 */
export interface CreateLessonTaskRequest {
  /** 课程名称 */
  courseName: string;
  /** 微课名称 */
  microLessonName: string;
  /** 用户ID */
  userId: number;
  /** 建议信息 */
  advise?: string;
}

/**
 * 更新课程任务请求参数接口
 */
export interface UpdateLessonTaskRequest {
  /** 课程名称 */
  courseName?: string;
  /** 微课名称 */
  microLessonName?: string;
  /** 用户ID */
  userId?: number;
  /** 进度状态 */
  progressStatus?: number;
  /** 脚本上传时间 */
  scriptUploadTime?: number;
  /** 脚本确认时间 */
  scriptConfirmTime?: number;
  /** 视频拍摄时间 */
  videoCaptureTime?: number;
  /** 视频确认时间 */
  videoConfirmTime?: number;
  /** 完成时间 */
  finishTime?: number;
  /** 建议信息 */
  advise?: string;
}
