export interface User {
  id: number;
  username: string;
  email: string;
  departmentId: number;
  roles: number;
  jobs: number;
  avatar: string | null;
  creatorId: number;
  status: number;
  createdAt: number;
  updatedAt: number;
  enabled: boolean;
  authorities: Authority[];
}

export interface Authority {
  authority: string;
}

// 角色枚举
export enum Roles {
  TEACHER = 1,        // 教师
  GENERAL_ADMIN = 2,  // 普通管理员
  CONTACTOR = 3,      // 沟通联络人
  SYSTEM_ADMIN = 4    // 系统管理员
}

// 岗位枚举
export enum Jobs {
  COURSE_TEACHER = 1,     // 课程制作教师
  PROJECT_MANAGER = 2,    // 课程购买方项目负责人
  COURSE_CONTACTOR = 3,   // 课程制作方沟通联络人
  SYSTEM_MANAGER = 4      // 系统制作方项目负责人
}

// 用户状态枚举
export enum UserStatus {
  DISABLED = 0,  // 禁用
  ENABLED = 1    // 正常
}

export interface UserPagination {
  list: User[];
  total: number;
  currentPage: number;
  pageSize: number;
}

/**
 * 创建用户请求参数接口
 */
export interface CreateUserRequest {
  /** 用户名 */
  username: string;
  /** 邮箱 */
  email: string;
  /** 密码 */
  password: string;
  /** 部门ID */
  departmentId: number;
  /** 角色 */
  roles: number;
  /** 岗位 */
  jobs: number;
  /** 头像 */
  avatar?: string;
  /** 创建者ID */
  creatorId: number;
}
